==> 0.0.20.tar.gz: lib/src/repository/story.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/story.dart';
import 'package:uuid/uuid.dart';
import 'package:http/http.dart' as http;

abstract class StoryRepository {
  Future<AppResponse<bool>> createStory(Story story);
  Future<AppResponse<List<Story>>> getStories();
  Future<AppResponse<bool>> deleteStory(String storyId);
  Future<AppResponse<bool>> addStorySeen(String id);
}

class StoryTestRepository extends StoryRepository {
  final List<Story> _stories;

  StoryTestRepository()
      : _stories = [
          Story.named(
            id: "122",
            background: StoryVideo.named(
              url:
                  "https://firebasestorage.googleapis.com/v0/b/fairpriceit-a7636.appspot.com/o/1883334546.mp4?alt=media&token=48e21ccd-ad90-478f-b979-f8280684e0f8",
              thumbnail:
                  "https://images.pexels.com/photos/3076511/pexels-photo-3076511.jpeg?auto=compress&cs=tinysrgb&dpr=2&h=750&w=1260",
            ),
            thumbnail:
                "https://images.pexels.com/photos/3076511/pexels-photo-3076511.jpeg?auto=compress&cs=tinysrgb&dpr=2&h=750&w=1260",
            user: StoryUser.named(
                id: "1",
                name: "Osi Peters",
                profilePic:
                    "https://specials-images.forbesimg.com/imageserve/1219616367/960x0.jpg?fit=scale"),
            recordedAt: DateTime.now(),
          ),
        ];

  @override
  Future<AppResponse<bool>> createStory(Story story) async {
    await Future.delayed(Duration(seconds: 1));
    String id = Uuid().v4();
    story = story.copyWith(recordedAt: DateTime.now(), user: testUser, id: id);
    _stories.add(story);
    return AppResponse.named(data: true);
  }

  @override
  Future<AppResponse<List<Story>>> getStories() async {
    return AppResponse.named(data: _stories);
  }

  StoryUser get testUser => StoryUser.named(
      id: "1",
      name: "Osi Peters",
      profilePic:
          "https://specials-images.forbesimg.com/imageserve/1219616367/960x0.jpg?fit=scale");

  @override
  Future<AppResponse<bool>> addStorySeen(String id) {
    // TODO: implement addStorySeen
    throw UnimplementedError();
  }

  @override
  Future<AppResponse<bool>> deleteStory(String storyId) {
    // TODO: implement deleteStory
    throw UnimplementedError();
  }
}

class StoryNetworkRepository extends StoryRepository {
  final http.BaseClient client;

  StoryNetworkRepository(this.client);

  @override
  Future<AppResponse<bool>> addStorySeen(String id) async {
    try {
      String url = '/story/$id/seen/';
      var response = await client.post(
        url,
      );
      debugPrint("Response ${response.body}");
      return AppResponse.named(data: true);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> createStory(Story story) async {
    try {
      String url = '/story/';
      var json = story.toJson();
      debugPrint("Json $json");
      var response = await client.post(url,
          body: jsonEncode(json), headers: ApiConfig.headers);
      debugPrint("Response ${response.body}");
      return AppResponse.named(data: true);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> deleteStory(String storyId) async {
    try {
      String url = '/story/$storyId';
      var response = await client.delete(
        url,
      );
      debugPrint("Response ${response.body}");
      return AppResponse.named(data: true);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<List<Story>>> getStories() async {
    try {
      String url = '/story/';
      var response = await client.get(
        url + "?count=10",
      );
      debugPrint("Response ${response.body}");
      return AppResponse.named(error: "Not implemented");
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: e.toString());
    }
  }
}

==> 0.0.21.tar.gz: lib/src/repository/story.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/story.dart';
import 'package:ocg_user/ocg_user.dart';
import 'package:uuid/uuid.dart';
import 'package:http/http.dart' as http;

abstract class StoryRepository {
  Future<AppResponse<bool>> createStory(Story story);
  Future<AppResponse<List<Story>>> getStories();
  Future<AppResponse<bool>> deleteStory(String storyId);
  Future<AppResponse<bool>> addStorySeen(String id);
}

class StoryTestRepository extends StoryRepository {
  final List<Story> _stories;

  StoryTestRepository()
      : _stories = [
          Story.named(
            id: "122",
            background: StoryVideo.named(
              url:
                  "https://firebasestorage.googleapis.com/v0/b/fairpriceit-a7636.appspot.com/o/1883334546.mp4?alt=media&token=48e21ccd-ad90-478f-b979-f8280684e0f8",
              thumbnail:
                  "https://images.pexels.com/photos/3076511/pexels-photo-3076511.jpeg?auto=compress&cs=tinysrgb&dpr=2&h=750&w=1260",
            ),
            createdAt: DateTime.now(),
          ),
        ];

  @override
  Future<AppResponse<bool>> createStory(Story story) async {
    await Future.delayed(Duration(seconds: 1));
    String id = Uuid().v4();
    story = story.copyWith(id: id);
    _stories.add(story);
    return AppResponse.named(data: true);
  }

  @override
  Future<AppResponse<List<Story>>> getStories() async {
    return AppResponse.named(data: _stories);
  }

  StoryUser get testUser => StoryUser.named(
      id: "1",
      name: "Osi Peters",
      profilePic:
          "https://specials-images.forbesimg.com/imageserve/1219616367/960x0.jpg?fit=scale");

  @override
  Future<AppResponse<bool>> addStorySeen(String id) {
    // TODO: implement addStorySeen
    throw UnimplementedError();
  }

  @override
  Future<AppResponse<bool>> deleteStory(String storyId) {
    // TODO: implement deleteStory
    throw UnimplementedError();
  }
}

class StoryNetworkRepository extends StoryRepository {
  final http.BaseClient client;
  final UserRepository userRepository;

  StoryNetworkRepository(this.client, this.userRepository);

  @override
  Future<AppResponse<bool>> addStorySeen(String id) async {
    try {
      String url = '/story/$id/seen/';
      var response = await client.post(
        url,
      );
      debugPrint("Response ${response.body}");
      return AppResponse.named(data: true);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> createStory(Story story) async {
    try {
      String url = '/story/';
      var json = story.toJson();
      debugPrint("Json $json");
      var response = await client.post(url,
          body: jsonEncode(json), headers: ApiConfig.headers);
      return AppResponse.named(data: true);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> deleteStory(String storyId) async {
    try {
      String url = '/story/$storyId';
      var response = await client.delete(
        url,
      );
      debugPrint("Response ${response.body}");
      return AppResponse.named(data: true);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<List<Story>>> getStories() async {
    try {
      String url = '/story/';
      var response = await client.get(
        url + "?count=10",
      );
      var json = jsonDecode(response.body);
      var stories = List<Story>.from(((json["stories"] ?? []) as List).map((e) {
        return Story.fromJson(e);
      })).toList();
      var userStories = await Future.wait(stories.map((e) async {
        AppResponse<User> userResponse = await userRepository.getUser(e.userId);
        if (userResponse.isSuccess) {
          return e.copyWith(user: userResponse.data);
        }
      }));
      userStories = userStories.where((element) => element != null).toList();
      return AppResponse.named(data: []);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: e.toString());
    }
  }
}
